@@ -10,7 +10,11 @@ if have_appserver:
     appid = get_application_id()
 else:
     try:
-        from google.appengine.tools import dev_appserver
+        try:
+            from google.appengine.tools import dev_appserver
+        except ImportError:
+            from google.appengine.tools import old_dev_appserver as dev_appserver
+
         from .boot import PROJECT_DIR
         appconfig = dev_appserver.LoadAppConfig(PROJECT_DIR, {},
                                                 default_partition='dev')[0]
